﻿using System;
using System.IO;
using System.Reflection;
using System.Security.Cryptography;

namespace Katteker
{
    /// <summary>
    /// Utilities.
    /// </summary>
    public static class Utility
    {
        internal static string GetLocalAppDataDirectory()
        {
            return Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData);
        }

        internal static string GetApplicationName()
        {
            return Assembly.GetEntryAssembly().GetName().Name;
        }

        /// <summary>
        /// Is true if the url is a web-address. False otherwise.
        /// </summary>
        /// <param name="urlOrPath"></param>
        /// <returns></returns>
        public static bool IsWebUrl(string urlOrPath)
        {
            var uri = new Uri(urlOrPath);
            return uri.Scheme == "http" || uri.Scheme == "https";
        }

        /// <summary>
        /// Compute file hash with SHA1. 
        /// If the file is greater than 5 MB, the hash will only computed with the first 5 MB.
        /// </summary>
        /// <param name="filename"></param>
        /// <returns></returns>
        public static string ComputeFileHash(string filename)
        {
            string sha1;
            var fileInfo = new FileInfo(filename);

            using (var fileStream = fileInfo.OpenRead())
            {
                var buffer = new byte[5242880];
                fileStream.Read(buffer, 0, buffer.Length);
                var sha1Managed = new SHA1Managed();
                sha1 = Convert.ToBase64String(sha1Managed.ComputeHash(buffer));
            }
            return sha1;
        }
    }
}